@@ -61,7 +61,7 @@ __PACKAGE__->response_class('Catalyst::Response');
 
 # Remember to update this in Catalyst::Runtime as well!
 
-our $VERSION = '5.70_02';
+our $VERSION = '5.70_03';
 
 sub import {
     my ( $class, @arguments ) = @_;
@@ -792,15 +792,7 @@ EOF
     }
     
     if ( $class->debug ) {
-
-        my @plugins = ();
-
-        {
-            no strict 'refs';
-            @plugins =
-              map { $_ . ' ' . ( $_->VERSION || '' ) }
-              grep { /^Catalyst::Plugin/ } @{"$class\::ISA"};
-        }
+        my @plugins = map { "$_  " . ( $_->VERSION || '' ) } $class->registered_plugins;
 
         if (@plugins) {
             my $t = Text::SimpleTable->new(74);
